==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/download.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!$CONF['download']) die(_DISABLED);
include("$CONF[G_PATH]/include/kmod/download/index.php");
ini_set('max_execution_time',$CONF['dn_maxtime']);
ini_set('upload_max_filesize',$CONF['dn_maxsize']);

$A['Heading'] = _DOWNLOAD . ": ";

settype($mode, "string");
switch ($mode) {
   case "download":
      download_file($id);
   break;

   case "filelink":
      if ($CONF['dn_mode']) {
         $filelink = KWL_UrlCheck($filelink);
         $filename = trim($filename);
         if (empty($filename)) KWL_ShowError(_FNAME_EMPTY);
         elseif (empty($filelink)) KWL_ShowError(_NOT_VALID_URL);
			$url = KWL_UrlCheck($url);
         $passwd = crypt($passwd);
         $description = trim($description);
         $uname = KWL_PrepareHtml($uname);
         if ($login && is_array($user)) {
            $uname = $user['name'];
            $passwd = $user['pass'];
         }
         if ($CONF['dn_mode']>1 || $CONF['admin_login']) { $txt = _UPLOADED; $val = 1; }
         else { $txt = _UPLOADED . "<BR>" . _UPLOADED2; $val = 0; }
         $sql = "INSERT INTO T_Download (Verified, hit, path, filename, date, url, category, description, uname, passwd) VALUES ('$val', 0, '$filelink', '$filename', '". time() ."', '$url', '$category', '$description', '$uname', '$passwd')";
         if (SqlQuery($sql)) {
            include("include/header.inc.php");
            $A['Content'] = "<BR><CENTER><B>$txt"
               ."</B><P>[ <A href=\"$CONF[G_URL]\">"
               . KWL_PrepareHtml($CONF['SiteName']) ."</A> - "
               . KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</CENTER><BR>";
            $A['Heading'] = _DOWNLOAD;
            KWL_DrawMain($A);
            include("include/footer.inc.php");
            exit;
         } else die(_SQL_ERROR);
      } die("upload not permit!");
   break;

   case "fileup":
      if ($CONF['dn_mode']) {
         $updir = date("YmdHis",time());
         $file = KWL_FileUpload($_FILES['userfile'],"$CONF[G_PATH]/$CONF[dn_path]/$category",$updir,$CONF['dn_maxsize']);
         
         if (is_array($file)) {
            $url = KWL_UrlCheck($url);
            $passwd = crypt($passwd);
            $description = trim($description);
            $uname = htmlspecialchars(trim($uname));
            if ($login && is_array($user)) {
               $uname = $user['name'];
               $passwd = $user['pass'];
            }
            if ($CONF['dn_mode']>1 || $CONF['admin_login']) { $txt = _UPLOADED; $val = 1; }
            else { $txt = _UPLOADED . "<BR>" . _UPLOADED2; $val = 0; }
            $sql = "INSERT INTO T_Download (Verified, hit, path, filename, filesize, date, url, category, description, uname, passwd) VALUES ('$val', 0, '$updir', '$file[name]', '$file[size]', '". time() ."', '$url', '$category', '$description', '$uname' , '$passwd')";
            if (SqlQuery($sql)) {
               include("include/header.inc.php");
               $A['Content'] = "<BR><CENTER><B>$txt"
                  ."</B><P>[ <A href=\"$CONF[G_URL]\">"
                  . KWL_PrepareHtml($CONF['SiteName']) ."</A> - "
                  . KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</CENTER><BR>";
               $A['Heading'] = _DOWNLOAD;
               KWL_DrawMain($A);
               include("include/footer.inc.php");
               KWL_Redirect("download.php",1,3);
               exit;
            } else die(_SQL_ERROR);
         } else KWL_ShowError(_UPLOAD_FAILED);
      } else die("upload not permit!");
   break;

   case "killfile":
      if (check_fpasswd($id,$passwd)) {
         if ($id) kill_file($id);
         KWL_Redirect("download.php",1);
      } else KWL_ShowError(_PASS_NO);
   break;
   
   case "updatefile":
      if (!KWL_HcodeCheck($filename.$oldfilepath.$id.$oldc.$mode,$hcode)) {
         KWL_Redirect("download.php",1);
      }
      if (check_fpasswd($id,$passwd)) {
         if ($deletefile == "on" && $id) {
            kill_file($id);
            KWL_Redirect("download.php",1);
            exit;
         }
         $uname = htmlspecialchars(trim($uname));
         $url = KWL_UrlCheck($url);
         $description = trim($description);

         $sql = "UPDATE T_Download SET url = '$url', category = '$category' , description = '$description', uname = '$uname' WHERE id = '$id'";
         if (SqlQuery($sql)) {
            if ($oldc != $category) {
               if (!file_exists("$CONF[dn_path]/$category")) mkdir("$CONF[dn_path]/$category",0755);
               exec("$exec[mv] \"$CONF[dn_path]/$oldc/$oldfilepath\" \"$CONF[dn_path]/$category/\"");
            }
            KWL_Redirect("download.php?categories=$category");
            exit;
         } else KWL_ShowError(_SQL_ERROR);
      } else KWL_ShowError(_PASS_NO);
   break;
	
   case "upload":
      $A['Heading'] .= _UPLOAD;
      $A['Content'] = upload_form($categories);
   break;

   case "uplink":
      $A['Heading'] .= _UPLINK;
      $A['Content'] = upload_form($categories,1);
   break;

   case "viewinfo":
      $A['Heading'] .= _VIEW_FILE_INFO;
      $A['Content'] = view_file_info($id);
   break;

   case "edit":
      $A['Heading'] .= _EDIT;
      $A['Content'] = edit_file($id);
   break;

   default:
      settype($sort, "string");
      settype($page, "integer");
      if (!empty($categories)) $A['Heading'] .= get_category($categories);
      else $categories = "";
      $A['Content'] = show_category($categories) . show_files($sort,$categories,$page);
}

$head = _DOWNLOAD;
include("include/header.inc.php");
KWL_DrawMain($A);
include("include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/download.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!$CONF['download']) die(_DISABLED);
include("$CONF[G_PATH]/include/kmod/download/index.php");
ini_set('max_execution_time',$CONF['dn_maxtime']);
ini_set('upload_max_filesize',$CONF['dn_maxsize']);

$A['Heading'] = _DOWNLOAD . ": ";

settype($mode, "string");
switch ($mode) {
   case "download":
      download_file($id);
   break;

   case "filelink":
      if ($CONF['dn_mode']) {
         $filelink = KWL_UrlCheck($filelink);
         $filename = trim($filename);
         if (empty($filename)) KWL_ShowError(_FNAME_EMPTY);
         elseif (empty($filelink)) KWL_ShowError(_NOT_VALID_URL);
			$url = KWL_UrlCheck($url);
         $passwd = crypt($passwd);
         $description = trim($description);
         $uname = KWL_PrepareHtml($uname);
         if ($login && is_array($user)) {
            $uname = $user['name'];
            $passwd = $user['pass'];
         }
         if ($CONF['dn_mode']>1 || $CONF['admin_login']) { $txt = _UPLOADED; $val = 1; }
         else { $txt = _UPLOADED . "<br />" . _UPLOADED2; $val = 0; }
         $sql = "INSERT INTO T_Download (Verified, hit, path, filename, date, url, category, description, uname, passwd) VALUES ('$val', 0, '$filelink', '$filename', '". time() ."', '$url', '$category', '$description', '$uname', '$passwd')";
         if (SqlQuery($sql)) {
            include("include/header.inc.php");
            $A['Content'] = "<br /><center><b>$txt"
               ."</b><p />[ <a href=\"$CONF[G_URL]\">"
               . KWL_PrepareHtml($CONF['SiteName']) ."</a> - "
               . KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</center><br />";
            $A['Heading'] = _DOWNLOAD;
            KWL_DrawMain($A);
            include("include/footer.inc.php");
            exit;
         } else die(_SQL_ERROR);
      } die("upload not permit!");
   break;

   case "fileup":
      if ($CONF['dn_mode']) {
         $updir = date("YmdHis",time());
         $file = KWL_FileUpload($_FILES['userfile'],"$CONF[G_PATH]/$CONF[dn_path]/$category",$updir,$CONF['dn_maxsize']);
         
         if (is_array($file)) {
            $url = KWL_UrlCheck($url);
            $passwd = crypt($passwd);
            $description = trim($description);
            $uname = htmlspecialchars(trim($uname));
            if ($login && is_array($user)) {
               $uname = $user['name'];
               $passwd = $user['pass'];
            }
            if ($CONF['dn_mode']>1 || $CONF['admin_login']) { $txt = _UPLOADED; $val = 1; }
            else { $txt = _UPLOADED . "<br />" . _UPLOADED2; $val = 0; }
            $sql = "INSERT INTO T_Download (Verified, hit, path, filename, filesize, date, url, category, description, uname, passwd) VALUES ('$val', 0, '$updir', '$file[name]', '$file[size]', '". time() ."', '$url', '$category', '$description', '$uname' , '$passwd')";
            if (SqlQuery($sql)) {
               include("include/header.inc.php");
               $A['Content'] = "<br /><center><b>$txt"
                  ."</b><p />[ <a href=\"$CONF[G_URL]\">"
                  . KWL_PrepareHtml($CONF['SiteName']) ."</a> - "
                  . KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</center><br />";
               $A['Heading'] = _DOWNLOAD;
               KWL_DrawMain($A);
               include("include/footer.inc.php");
               KWL_Redirect("download.php",1,3);
               exit;
            } else die(_SQL_ERROR);
         } else KWL_ShowError(_UPLOAD_FAILED);
      } else die("upload not permit!");
   break;

   case "killfile":
      if (check_fpasswd($id,$passwd)) {
         if ($id) kill_file($id);
         KWL_Redirect("download.php",1);
      } else KWL_ShowError(_PASS_NO);
   break;
   
   case "updatefile":
      if (!KWL_HcodeCheck($filename.$oldfilepath.$id.$oldc.$mode,$hcode)) {
         KWL_Redirect("download.php",1);
      }
      if (check_fpasswd($id,$passwd)) {
         if ($deletefile == "on" && $id) {
            kill_file($id);
            KWL_Redirect("download.php",1);
            exit;
         }
         $uname = htmlspecialchars(trim($uname));
         $url = KWL_UrlCheck($url);
         $description = trim($description);

         $sql = "UPDATE T_Download SET url = '$url', category = '$category' , description = '$description', uname = '$uname' WHERE id = '$id'";
         if (SqlQuery($sql)) {
            if ($oldc != $category) {
               if (!file_exists("$CONF[dn_path]/$category")) mkdir("$CONF[dn_path]/$category",0755);
               exec("$exec[mv] \"$CONF[dn_path]/$oldc/$oldfilepath\" \"$CONF[dn_path]/$category/\"");
            }
            KWL_Redirect("download.php?categories=$category");
            exit;
         } else KWL_ShowError(_SQL_ERROR);
      } else KWL_ShowError(_PASS_NO);
   break;
	
   case "upload":
      $A['Heading'] .= _UPLOAD;
      $A['Content'] = upload_form($categories);
   break;

   case "uplink":
      $A['Heading'] .= _UPLINK;
      $A['Content'] = upload_form($categories,1);
   break;

   case "viewinfo":
      $A['Heading'] .= _VIEW_FILE_INFO;
      $A['Content'] = view_file_info($id);
   break;

   case "edit":
      $A['Heading'] .= _EDIT;
      $A['Content'] = edit_file($id);
   break;

   default:
      settype($sort, "string");
      settype($page, "integer");
      if (!empty($categories)) $A['Heading'] .= get_category($categories);
      else $categories = "";
      $A['Content'] = show_category($categories) . show_files($sort,$categories,$page);
}

$head = _DOWNLOAD;
include("include/header.inc.php");
KWL_DrawMain($A);
include("include/footer.inc.php");
?>
